package yerushalmi_test

import (
	"fmt"
	"testing"
	"time"

	"github.com/hebcal/hdate"
	"github.com/hebcal/hebcal-go/dafyomi"
	"github.com/hebcal/hebcal-go/yerushalmi"
	"github.com/stretchr/testify/assert"
)

func TestYerushalmiYomi(t *testing.T) {
	assert := assert.New(t)
	assert.Equal(dafyomi.Daf{Name: "Berakhot", Blatt: 1},
		yerushalmi.New(hdate.FromGregorian(1997, time.March, 14), yerushalmi.Vilna))
	assert.Equal(dafyomi.Daf{Name: "Berakhot", Blatt: 2},
		yerushalmi.New(hdate.FromGregorian(1997, time.March, 15), yerushalmi.Vilna))
	assert.Equal(dafyomi.Daf{Name: "Berakhot", Blatt: 3},
		yerushalmi.New(hdate.FromGregorian(1997, time.March, 16), yerushalmi.Vilna))
	assert.Equal(dafyomi.Daf{Name: "Yevamot", Blatt: 49},
		yerushalmi.New(hdate.FromGregorian(1999, time.September, 21), yerushalmi.Vilna))
	assert.Equal(dafyomi.Daf{Name: "Niddah", Blatt: 13},
		yerushalmi.New(hdate.FromGregorian(2001, time.June, 22), yerushalmi.Vilna))
	assert.Equal(dafyomi.Daf{Name: "Berakhot", Blatt: 1},
		yerushalmi.New(hdate.FromGregorian(2022, time.November, 14), yerushalmi.Vilna))
	assert.Equal(dafyomi.Daf{Name: "Peah", Blatt: 1},
		yerushalmi.New(hdate.FromGregorian(2023, time.January, 21), yerushalmi.Vilna))
	assert.Equal(dafyomi.Daf{Name: "Berakhot", Blatt: 1},
		yerushalmi.New(hdate.FromGregorian(1980, time.February, 2), yerushalmi.Vilna))
}

func TestYerushalmiYomi2(t *testing.T) {
	actual := make([]string, 0, 1563)
	start := hdate.FromGregorian(1997, time.March, 14)
	end := hdate.FromGregorian(2001, time.June, 22)
	endAbs := end.Abs()
	for abs := start.Abs(); abs <= endAbs; abs++ {
		hd := hdate.FromRD(abs)
		daf := yerushalmi.New(hd, yerushalmi.Vilna)
		actual = append(actual, hd.String()+","+daf.String())
	}
	expected := []string{
		"5 Adar II 5757,Berakhot 1",
		"6 Adar II 5757,Berakhot 2",
		"7 Adar II 5757,Berakhot 3",
		"8 Adar II 5757,Berakhot 4",
		"9 Adar II 5757,Berakhot 5",
		"10 Adar II 5757,Berakhot 6",
		"11 Adar II 5757,Berakhot 7",
		"12 Adar II 5757,Berakhot 8",
		"13 Adar II 5757,Berakhot 9",
		"14 Adar II 5757,Berakhot 10",
		"15 Adar II 5757,Berakhot 11",
		"16 Adar II 5757,Berakhot 12",
		"17 Adar II 5757,Berakhot 13",
		"18 Adar II 5757,Berakhot 14",
		"19 Adar II 5757,Berakhot 15",
		"20 Adar II 5757,Berakhot 16",
		"21 Adar II 5757,Berakhot 17",
		"22 Adar II 5757,Berakhot 18",
		"23 Adar II 5757,Berakhot 19",
		"24 Adar II 5757,Berakhot 20",
		"25 Adar II 5757,Berakhot 21",
		"26 Adar II 5757,Berakhot 22",
		"27 Adar II 5757,Berakhot 23",
		"28 Adar II 5757,Berakhot 24",
		"29 Adar II 5757,Berakhot 25",
		"1 Nisan 5757,Berakhot 26",
		"2 Nisan 5757,Berakhot 27",
		"3 Nisan 5757,Berakhot 28",
		"4 Nisan 5757,Berakhot 29",
		"5 Nisan 5757,Berakhot 30",
		"6 Nisan 5757,Berakhot 31",
		"7 Nisan 5757,Berakhot 32",
		"8 Nisan 5757,Berakhot 33",
		"9 Nisan 5757,Berakhot 34",
		"10 Nisan 5757,Berakhot 35",
		"11 Nisan 5757,Berakhot 36",
		"12 Nisan 5757,Berakhot 37",
		"13 Nisan 5757,Berakhot 38",
		"14 Nisan 5757,Berakhot 39",
		"15 Nisan 5757,Berakhot 40",
		"16 Nisan 5757,Berakhot 41",
		"17 Nisan 5757,Berakhot 42",
		"18 Nisan 5757,Berakhot 43",
		"19 Nisan 5757,Berakhot 44",
		"20 Nisan 5757,Berakhot 45",
		"21 Nisan 5757,Berakhot 46",
		"22 Nisan 5757,Berakhot 47",
		"23 Nisan 5757,Berakhot 48",
		"24 Nisan 5757,Berakhot 49",
		"25 Nisan 5757,Berakhot 50",
		"26 Nisan 5757,Berakhot 51",
		"27 Nisan 5757,Berakhot 52",
		"28 Nisan 5757,Berakhot 53",
		"29 Nisan 5757,Berakhot 54",
		"30 Nisan 5757,Berakhot 55",
		"1 Iyyar 5757,Berakhot 56",
		"2 Iyyar 5757,Berakhot 57",
		"3 Iyyar 5757,Berakhot 58",
		"4 Iyyar 5757,Berakhot 59",
		"5 Iyyar 5757,Berakhot 60",
		"6 Iyyar 5757,Berakhot 61",
		"7 Iyyar 5757,Berakhot 62",
		"8 Iyyar 5757,Berakhot 63",
		"9 Iyyar 5757,Berakhot 64",
		"10 Iyyar 5757,Berakhot 65",
		"11 Iyyar 5757,Berakhot 66",
		"12 Iyyar 5757,Berakhot 67",
		"13 Iyyar 5757,Berakhot 68",
		"14 Iyyar 5757,Peah 1",
		"15 Iyyar 5757,Peah 2",
		"16 Iyyar 5757,Peah 3",
		"17 Iyyar 5757,Peah 4",
		"18 Iyyar 5757,Peah 5",
		"19 Iyyar 5757,Peah 6",
		"20 Iyyar 5757,Peah 7",
		"21 Iyyar 5757,Peah 8",
		"22 Iyyar 5757,Peah 9",
		"23 Iyyar 5757,Peah 10",
		"24 Iyyar 5757,Peah 11",
		"25 Iyyar 5757,Peah 12",
		"26 Iyyar 5757,Peah 13",
		"27 Iyyar 5757,Peah 14",
		"28 Iyyar 5757,Peah 15",
		"29 Iyyar 5757,Peah 16",
		"1 Sivan 5757,Peah 17",
		"2 Sivan 5757,Peah 18",
		"3 Sivan 5757,Peah 19",
		"4 Sivan 5757,Peah 20",
		"5 Sivan 5757,Peah 21",
		"6 Sivan 5757,Peah 22",
		"7 Sivan 5757,Peah 23",
		"8 Sivan 5757,Peah 24",
		"9 Sivan 5757,Peah 25",
		"10 Sivan 5757,Peah 26",
		"11 Sivan 5757,Peah 27",
		"12 Sivan 5757,Peah 28",
		"13 Sivan 5757,Peah 29",
		"14 Sivan 5757,Peah 30",
		"15 Sivan 5757,Peah 31",
		"16 Sivan 5757,Peah 32",
		"17 Sivan 5757,Peah 33",
		"18 Sivan 5757,Peah 34",
		"19 Sivan 5757,Peah 35",
		"20 Sivan 5757,Peah 36",
		"21 Sivan 5757,Peah 37",
		"22 Sivan 5757,Demai 1",
		"23 Sivan 5757,Demai 2",
		"24 Sivan 5757,Demai 3",
		"25 Sivan 5757,Demai 4",
		"26 Sivan 5757,Demai 5",
		"27 Sivan 5757,Demai 6",
		"28 Sivan 5757,Demai 7",
		"29 Sivan 5757,Demai 8",
		"30 Sivan 5757,Demai 9",
		"1 Tamuz 5757,Demai 10",
		"2 Tamuz 5757,Demai 11",
		"3 Tamuz 5757,Demai 12",
		"4 Tamuz 5757,Demai 13",
		"5 Tamuz 5757,Demai 14",
		"6 Tamuz 5757,Demai 15",
		"7 Tamuz 5757,Demai 16",
		"8 Tamuz 5757,Demai 17",
		"9 Tamuz 5757,Demai 18",
		"10 Tamuz 5757,Demai 19",
		"11 Tamuz 5757,Demai 20",
		"12 Tamuz 5757,Demai 21",
		"13 Tamuz 5757,Demai 22",
		"14 Tamuz 5757,Demai 23",
		"15 Tamuz 5757,Demai 24",
		"16 Tamuz 5757,Demai 25",
		"17 Tamuz 5757,Demai 26",
		"18 Tamuz 5757,Demai 27",
		"19 Tamuz 5757,Demai 28",
		"20 Tamuz 5757,Demai 29",
		"21 Tamuz 5757,Demai 30",
		"22 Tamuz 5757,Demai 31",
		"23 Tamuz 5757,Demai 32",
		"24 Tamuz 5757,Demai 33",
		"25 Tamuz 5757,Demai 34",
		"26 Tamuz 5757,Kilayim 1",
		"27 Tamuz 5757,Kilayim 2",
		"28 Tamuz 5757,Kilayim 3",
		"29 Tamuz 5757,Kilayim 4",
		"1 Av 5757,Kilayim 5",
		"2 Av 5757,Kilayim 6",
		"3 Av 5757,Kilayim 7",
		"4 Av 5757,Kilayim 8",
		"5 Av 5757,Kilayim 9",
		"6 Av 5757,Kilayim 10",
		"7 Av 5757,Kilayim 11",
		"8 Av 5757,Kilayim 12",
		"9 Av 5757,%!Daf(,0)",
		"10 Av 5757,Kilayim 13",
		"11 Av 5757,Kilayim 14",
		"12 Av 5757,Kilayim 15",
		"13 Av 5757,Kilayim 16",
		"14 Av 5757,Kilayim 17",
		"15 Av 5757,Kilayim 18",
		"16 Av 5757,Kilayim 19",
		"17 Av 5757,Kilayim 20",
		"18 Av 5757,Kilayim 21",
		"19 Av 5757,Kilayim 22",
		"20 Av 5757,Kilayim 23",
		"21 Av 5757,Kilayim 24",
		"22 Av 5757,Kilayim 25",
		"23 Av 5757,Kilayim 26",
		"24 Av 5757,Kilayim 27",
		"25 Av 5757,Kilayim 28",
		"26 Av 5757,Kilayim 29",
		"27 Av 5757,Kilayim 30",
		"28 Av 5757,Kilayim 31",
		"29 Av 5757,Kilayim 32",
		"30 Av 5757,Kilayim 33",
		"1 Elul 5757,Kilayim 34",
		"2 Elul 5757,Kilayim 35",
		"3 Elul 5757,Kilayim 36",
		"4 Elul 5757,Kilayim 37",
		"5 Elul 5757,Kilayim 38",
		"6 Elul 5757,Kilayim 39",
		"7 Elul 5757,Kilayim 40",
		"8 Elul 5757,Kilayim 41",
		"9 Elul 5757,Kilayim 42",
		"10 Elul 5757,Kilayim 43",
		"11 Elul 5757,Kilayim 44",
		"12 Elul 5757,Sheviit 1",
		"13 Elul 5757,Sheviit 2",
		"14 Elul 5757,Sheviit 3",
		"15 Elul 5757,Sheviit 4",
		"16 Elul 5757,Sheviit 5",
		"17 Elul 5757,Sheviit 6",
		"18 Elul 5757,Sheviit 7",
		"19 Elul 5757,Sheviit 8",
		"20 Elul 5757,Sheviit 9",
		"21 Elul 5757,Sheviit 10",
		"22 Elul 5757,Sheviit 11",
		"23 Elul 5757,Sheviit 12",
		"24 Elul 5757,Sheviit 13",
		"25 Elul 5757,Sheviit 14",
		"26 Elul 5757,Sheviit 15",
		"27 Elul 5757,Sheviit 16",
		"28 Elul 5757,Sheviit 17",
		"29 Elul 5757,Sheviit 18",
		"1 Tishrei 5758,Sheviit 19",
		"2 Tishrei 5758,Sheviit 20",
		"3 Tishrei 5758,Sheviit 21",
		"4 Tishrei 5758,Sheviit 22",
		"5 Tishrei 5758,Sheviit 23",
		"6 Tishrei 5758,Sheviit 24",
		"7 Tishrei 5758,Sheviit 25",
		"8 Tishrei 5758,Sheviit 26",
		"9 Tishrei 5758,Sheviit 27",
		"10 Tishrei 5758,%!Daf(,0)",
		"11 Tishrei 5758,Sheviit 28",
		"12 Tishrei 5758,Sheviit 29",
		"13 Tishrei 5758,Sheviit 30",
		"14 Tishrei 5758,Sheviit 31",
		"15 Tishrei 5758,Terumot 1",
		"16 Tishrei 5758,Terumot 2",
		"17 Tishrei 5758,Terumot 3",
		"18 Tishrei 5758,Terumot 4",
		"19 Tishrei 5758,Terumot 5",
		"20 Tishrei 5758,Terumot 6",
		"21 Tishrei 5758,Terumot 7",
		"22 Tishrei 5758,Terumot 8",
		"23 Tishrei 5758,Terumot 9",
		"24 Tishrei 5758,Terumot 10",
		"25 Tishrei 5758,Terumot 11",
		"26 Tishrei 5758,Terumot 12",
		"27 Tishrei 5758,Terumot 13",
		"28 Tishrei 5758,Terumot 14",
		"29 Tishrei 5758,Terumot 15",
		"30 Tishrei 5758,Terumot 16",
		"1 Cheshvan 5758,Terumot 17",
		"2 Cheshvan 5758,Terumot 18",
		"3 Cheshvan 5758,Terumot 19",
		"4 Cheshvan 5758,Terumot 20",
		"5 Cheshvan 5758,Terumot 21",
		"6 Cheshvan 5758,Terumot 22",
		"7 Cheshvan 5758,Terumot 23",
		"8 Cheshvan 5758,Terumot 24",
		"9 Cheshvan 5758,Terumot 25",
		"10 Cheshvan 5758,Terumot 26",
		"11 Cheshvan 5758,Terumot 27",
		"12 Cheshvan 5758,Terumot 28",
		"13 Cheshvan 5758,Terumot 29",
		"14 Cheshvan 5758,Terumot 30",
		"15 Cheshvan 5758,Terumot 31",
		"16 Cheshvan 5758,Terumot 32",
		"17 Cheshvan 5758,Terumot 33",
		"18 Cheshvan 5758,Terumot 34",
		"19 Cheshvan 5758,Terumot 35",
		"20 Cheshvan 5758,Terumot 36",
		"21 Cheshvan 5758,Terumot 37",
		"22 Cheshvan 5758,Terumot 38",
		"23 Cheshvan 5758,Terumot 39",
		"24 Cheshvan 5758,Terumot 40",
		"25 Cheshvan 5758,Terumot 41",
		"26 Cheshvan 5758,Terumot 42",
		"27 Cheshvan 5758,Terumot 43",
		"28 Cheshvan 5758,Terumot 44",
		"29 Cheshvan 5758,Terumot 45",
		"1 Kislev 5758,Terumot 46",
		"2 Kislev 5758,Terumot 47",
		"3 Kislev 5758,Terumot 48",
		"4 Kislev 5758,Terumot 49",
		"5 Kislev 5758,Terumot 50",
		"6 Kislev 5758,Terumot 51",
		"7 Kislev 5758,Terumot 52",
		"8 Kislev 5758,Terumot 53",
		"9 Kislev 5758,Terumot 54",
		"10 Kislev 5758,Terumot 55",
		"11 Kislev 5758,Terumot 56",
		"12 Kislev 5758,Terumot 57",
		"13 Kislev 5758,Terumot 58",
		"14 Kislev 5758,Terumot 59",
		"15 Kislev 5758,Maasrot 1",
		"16 Kislev 5758,Maasrot 2",
		"17 Kislev 5758,Maasrot 3",
		"18 Kislev 5758,Maasrot 4",
		"19 Kislev 5758,Maasrot 5",
		"20 Kislev 5758,Maasrot 6",
		"21 Kislev 5758,Maasrot 7",
		"22 Kislev 5758,Maasrot 8",
		"23 Kislev 5758,Maasrot 9",
		"24 Kislev 5758,Maasrot 10",
		"25 Kislev 5758,Maasrot 11",
		"26 Kislev 5758,Maasrot 12",
		"27 Kislev 5758,Maasrot 13",
		"28 Kislev 5758,Maasrot 14",
		"29 Kislev 5758,Maasrot 15",
		"30 Kislev 5758,Maasrot 16",
		"1 Tevet 5758,Maasrot 17",
		"2 Tevet 5758,Maasrot 18",
		"3 Tevet 5758,Maasrot 19",
		"4 Tevet 5758,Maasrot 20",
		"5 Tevet 5758,Maasrot 21",
		"6 Tevet 5758,Maasrot 22",
		"7 Tevet 5758,Maasrot 23",
		"8 Tevet 5758,Maasrot 24",
		"9 Tevet 5758,Maasrot 25",
		"10 Tevet 5758,Maasrot 26",
		"11 Tevet 5758,Maaser Sheni 1",
		"12 Tevet 5758,Maaser Sheni 2",
		"13 Tevet 5758,Maaser Sheni 3",
		"14 Tevet 5758,Maaser Sheni 4",
		"15 Tevet 5758,Maaser Sheni 5",
		"16 Tevet 5758,Maaser Sheni 6",
		"17 Tevet 5758,Maaser Sheni 7",
		"18 Tevet 5758,Maaser Sheni 8",
		"19 Tevet 5758,Maaser Sheni 9",
		"20 Tevet 5758,Maaser Sheni 10",
		"21 Tevet 5758,Maaser Sheni 11",
		"22 Tevet 5758,Maaser Sheni 12",
		"23 Tevet 5758,Maaser Sheni 13",
		"24 Tevet 5758,Maaser Sheni 14",
		"25 Tevet 5758,Maaser Sheni 15",
		"26 Tevet 5758,Maaser Sheni 16",
		"27 Tevet 5758,Maaser Sheni 17",
		"28 Tevet 5758,Maaser Sheni 18",
		"29 Tevet 5758,Maaser Sheni 19",
		"1 Sh'vat 5758,Maaser Sheni 20",
		"2 Sh'vat 5758,Maaser Sheni 21",
		"3 Sh'vat 5758,Maaser Sheni 22",
		"4 Sh'vat 5758,Maaser Sheni 23",
		"5 Sh'vat 5758,Maaser Sheni 24",
		"6 Sh'vat 5758,Maaser Sheni 25",
		"7 Sh'vat 5758,Maaser Sheni 26",
		"8 Sh'vat 5758,Maaser Sheni 27",
		"9 Sh'vat 5758,Maaser Sheni 28",
		"10 Sh'vat 5758,Maaser Sheni 29",
		"11 Sh'vat 5758,Maaser Sheni 30",
		"12 Sh'vat 5758,Maaser Sheni 31",
		"13 Sh'vat 5758,Maaser Sheni 32",
		"14 Sh'vat 5758,Maaser Sheni 33",
		"15 Sh'vat 5758,Challah 1",
		"16 Sh'vat 5758,Challah 2",
		"17 Sh'vat 5758,Challah 3",
		"18 Sh'vat 5758,Challah 4",
		"19 Sh'vat 5758,Challah 5",
		"20 Sh'vat 5758,Challah 6",
		"21 Sh'vat 5758,Challah 7",
		"22 Sh'vat 5758,Challah 8",
		"23 Sh'vat 5758,Challah 9",
		"24 Sh'vat 5758,Challah 10",
		"25 Sh'vat 5758,Challah 11",
		"26 Sh'vat 5758,Challah 12",
		"27 Sh'vat 5758,Challah 13",
		"28 Sh'vat 5758,Challah 14",
		"29 Sh'vat 5758,Challah 15",
		"30 Sh'vat 5758,Challah 16",
		"1 Adar 5758,Challah 17",
		"2 Adar 5758,Challah 18",
		"3 Adar 5758,Challah 19",
		"4 Adar 5758,Challah 20",
		"5 Adar 5758,Challah 21",
		"6 Adar 5758,Challah 22",
		"7 Adar 5758,Challah 23",
		"8 Adar 5758,Challah 24",
		"9 Adar 5758,Challah 25",
		"10 Adar 5758,Challah 26",
		"11 Adar 5758,Challah 27",
		"12 Adar 5758,Challah 28",
		"13 Adar 5758,Orlah 1",
		"14 Adar 5758,Orlah 2",
		"15 Adar 5758,Orlah 3",
		"16 Adar 5758,Orlah 4",
		"17 Adar 5758,Orlah 5",
		"18 Adar 5758,Orlah 6",
		"19 Adar 5758,Orlah 7",
		"20 Adar 5758,Orlah 8",
		"21 Adar 5758,Orlah 9",
		"22 Adar 5758,Orlah 10",
		"23 Adar 5758,Orlah 11",
		"24 Adar 5758,Orlah 12",
		"25 Adar 5758,Orlah 13",
		"26 Adar 5758,Orlah 14",
		"27 Adar 5758,Orlah 15",
		"28 Adar 5758,Orlah 16",
		"29 Adar 5758,Orlah 17",
		"1 Nisan 5758,Orlah 18",
		"2 Nisan 5758,Orlah 19",
		"3 Nisan 5758,Orlah 20",
		"4 Nisan 5758,Bikkurim 1",
		"5 Nisan 5758,Bikkurim 2",
		"6 Nisan 5758,Bikkurim 3",
		"7 Nisan 5758,Bikkurim 4",
		"8 Nisan 5758,Bikkurim 5",
		"9 Nisan 5758,Bikkurim 6",
		"10 Nisan 5758,Bikkurim 7",
		"11 Nisan 5758,Bikkurim 8",
		"12 Nisan 5758,Bikkurim 9",
		"13 Nisan 5758,Bikkurim 10",
		"14 Nisan 5758,Bikkurim 11",
		"15 Nisan 5758,Bikkurim 12",
		"16 Nisan 5758,Bikkurim 13",
		"17 Nisan 5758,Shabbat 1",
		"18 Nisan 5758,Shabbat 2",
		"19 Nisan 5758,Shabbat 3",
		"20 Nisan 5758,Shabbat 4",
		"21 Nisan 5758,Shabbat 5",
		"22 Nisan 5758,Shabbat 6",
		"23 Nisan 5758,Shabbat 7",
		"24 Nisan 5758,Shabbat 8",
		"25 Nisan 5758,Shabbat 9",
		"26 Nisan 5758,Shabbat 10",
		"27 Nisan 5758,Shabbat 11",
		"28 Nisan 5758,Shabbat 12",
		"29 Nisan 5758,Shabbat 13",
		"30 Nisan 5758,Shabbat 14",
		"1 Iyyar 5758,Shabbat 15",
		"2 Iyyar 5758,Shabbat 16",
		"3 Iyyar 5758,Shabbat 17",
		"4 Iyyar 5758,Shabbat 18",
		"5 Iyyar 5758,Shabbat 19",
		"6 Iyyar 5758,Shabbat 20",
		"7 Iyyar 5758,Shabbat 21",
		"8 Iyyar 5758,Shabbat 22",
		"9 Iyyar 5758,Shabbat 23",
		"10 Iyyar 5758,Shabbat 24",
		"11 Iyyar 5758,Shabbat 25",
		"12 Iyyar 5758,Shabbat 26",
		"13 Iyyar 5758,Shabbat 27",
		"14 Iyyar 5758,Shabbat 28",
		"15 Iyyar 5758,Shabbat 29",
		"16 Iyyar 5758,Shabbat 30",
		"17 Iyyar 5758,Shabbat 31",
		"18 Iyyar 5758,Shabbat 32",
		"19 Iyyar 5758,Shabbat 33",
		"20 Iyyar 5758,Shabbat 34",
		"21 Iyyar 5758,Shabbat 35",
		"22 Iyyar 5758,Shabbat 36",
		"23 Iyyar 5758,Shabbat 37",
		"24 Iyyar 5758,Shabbat 38",
		"25 Iyyar 5758,Shabbat 39",
		"26 Iyyar 5758,Shabbat 40",
		"27 Iyyar 5758,Shabbat 41",
		"28 Iyyar 5758,Shabbat 42",
		"29 Iyyar 5758,Shabbat 43",
		"1 Sivan 5758,Shabbat 44",
		"2 Sivan 5758,Shabbat 45",
		"3 Sivan 5758,Shabbat 46",
		"4 Sivan 5758,Shabbat 47",
		"5 Sivan 5758,Shabbat 48",
		"6 Sivan 5758,Shabbat 49",
		"7 Sivan 5758,Shabbat 50",
		"8 Sivan 5758,Shabbat 51",
		"9 Sivan 5758,Shabbat 52",
		"10 Sivan 5758,Shabbat 53",
		"11 Sivan 5758,Shabbat 54",
		"12 Sivan 5758,Shabbat 55",
		"13 Sivan 5758,Shabbat 56",
		"14 Sivan 5758,Shabbat 57",
		"15 Sivan 5758,Shabbat 58",
		"16 Sivan 5758,Shabbat 59",
		"17 Sivan 5758,Shabbat 60",
		"18 Sivan 5758,Shabbat 61",
		"19 Sivan 5758,Shabbat 62",
		"20 Sivan 5758,Shabbat 63",
		"21 Sivan 5758,Shabbat 64",
		"22 Sivan 5758,Shabbat 65",
		"23 Sivan 5758,Shabbat 66",
		"24 Sivan 5758,Shabbat 67",
		"25 Sivan 5758,Shabbat 68",
		"26 Sivan 5758,Shabbat 69",
		"27 Sivan 5758,Shabbat 70",
		"28 Sivan 5758,Shabbat 71",
		"29 Sivan 5758,Shabbat 72",
		"30 Sivan 5758,Shabbat 73",
		"1 Tamuz 5758,Shabbat 74",
		"2 Tamuz 5758,Shabbat 75",
		"3 Tamuz 5758,Shabbat 76",
		"4 Tamuz 5758,Shabbat 77",
		"5 Tamuz 5758,Shabbat 78",
		"6 Tamuz 5758,Shabbat 79",
		"7 Tamuz 5758,Shabbat 80",
		"8 Tamuz 5758,Shabbat 81",
		"9 Tamuz 5758,Shabbat 82",
		"10 Tamuz 5758,Shabbat 83",
		"11 Tamuz 5758,Shabbat 84",
		"12 Tamuz 5758,Shabbat 85",
		"13 Tamuz 5758,Shabbat 86",
		"14 Tamuz 5758,Shabbat 87",
		"15 Tamuz 5758,Shabbat 88",
		"16 Tamuz 5758,Shabbat 89",
		"17 Tamuz 5758,Shabbat 90",
		"18 Tamuz 5758,Shabbat 91",
		"19 Tamuz 5758,Shabbat 92",
		"20 Tamuz 5758,Eruvin 1",
		"21 Tamuz 5758,Eruvin 2",
		"22 Tamuz 5758,Eruvin 3",
		"23 Tamuz 5758,Eruvin 4",
		"24 Tamuz 5758,Eruvin 5",
		"25 Tamuz 5758,Eruvin 6",
		"26 Tamuz 5758,Eruvin 7",
		"27 Tamuz 5758,Eruvin 8",
		"28 Tamuz 5758,Eruvin 9",
		"29 Tamuz 5758,Eruvin 10",
		"1 Av 5758,Eruvin 11",
		"2 Av 5758,Eruvin 12",
		"3 Av 5758,Eruvin 13",
		"4 Av 5758,Eruvin 14",
		"5 Av 5758,Eruvin 15",
		"6 Av 5758,Eruvin 16",
		"7 Av 5758,Eruvin 17",
		"8 Av 5758,Eruvin 18",
		"9 Av 5758,Eruvin 19",
		"10 Av 5758,%!Daf(,0)",
		"11 Av 5758,Eruvin 20",
		"12 Av 5758,Eruvin 21",
		"13 Av 5758,Eruvin 22",
		"14 Av 5758,Eruvin 23",
		"15 Av 5758,Eruvin 24",
		"16 Av 5758,Eruvin 25",
		"17 Av 5758,Eruvin 26",
		"18 Av 5758,Eruvin 27",
		"19 Av 5758,Eruvin 28",
		"20 Av 5758,Eruvin 29",
		"21 Av 5758,Eruvin 30",
		"22 Av 5758,Eruvin 31",
		"23 Av 5758,Eruvin 32",
		"24 Av 5758,Eruvin 33",
		"25 Av 5758,Eruvin 34",
		"26 Av 5758,Eruvin 35",
		"27 Av 5758,Eruvin 36",
		"28 Av 5758,Eruvin 37",
		"29 Av 5758,Eruvin 38",
		"30 Av 5758,Eruvin 39",
		"1 Elul 5758,Eruvin 40",
		"2 Elul 5758,Eruvin 41",
		"3 Elul 5758,Eruvin 42",
		"4 Elul 5758,Eruvin 43",
		"5 Elul 5758,Eruvin 44",
		"6 Elul 5758,Eruvin 45",
		"7 Elul 5758,Eruvin 46",
		"8 Elul 5758,Eruvin 47",
		"9 Elul 5758,Eruvin 48",
		"10 Elul 5758,Eruvin 49",
		"11 Elul 5758,Eruvin 50",
		"12 Elul 5758,Eruvin 51",
		"13 Elul 5758,Eruvin 52",
		"14 Elul 5758,Eruvin 53",
		"15 Elul 5758,Eruvin 54",
		"16 Elul 5758,Eruvin 55",
		"17 Elul 5758,Eruvin 56",
		"18 Elul 5758,Eruvin 57",
		"19 Elul 5758,Eruvin 58",
		"20 Elul 5758,Eruvin 59",
		"21 Elul 5758,Eruvin 60",
		"22 Elul 5758,Eruvin 61",
		"23 Elul 5758,Eruvin 62",
		"24 Elul 5758,Eruvin 63",
		"25 Elul 5758,Eruvin 64",
		"26 Elul 5758,Eruvin 65",
		"27 Elul 5758,Pesachim 1",
		"28 Elul 5758,Pesachim 2",
		"29 Elul 5758,Pesachim 3",
		"1 Tishrei 5759,Pesachim 4",
		"2 Tishrei 5759,Pesachim 5",
		"3 Tishrei 5759,Pesachim 6",
		"4 Tishrei 5759,Pesachim 7",
		"5 Tishrei 5759,Pesachim 8",
		"6 Tishrei 5759,Pesachim 9",
		"7 Tishrei 5759,Pesachim 10",
		"8 Tishrei 5759,Pesachim 11",
		"9 Tishrei 5759,Pesachim 12",
		"10 Tishrei 5759,%!Daf(,0)",
		"11 Tishrei 5759,Pesachim 13",
		"12 Tishrei 5759,Pesachim 14",
		"13 Tishrei 5759,Pesachim 15",
		"14 Tishrei 5759,Pesachim 16",
		"15 Tishrei 5759,Pesachim 17",
		"16 Tishrei 5759,Pesachim 18",
		"17 Tishrei 5759,Pesachim 19",
		"18 Tishrei 5759,Pesachim 20",
		"19 Tishrei 5759,Pesachim 21",
		"20 Tishrei 5759,Pesachim 22",
		"21 Tishrei 5759,Pesachim 23",
		"22 Tishrei 5759,Pesachim 24",
		"23 Tishrei 5759,Pesachim 25",
		"24 Tishrei 5759,Pesachim 26",
		"25 Tishrei 5759,Pesachim 27",
		"26 Tishrei 5759,Pesachim 28",
		"27 Tishrei 5759,Pesachim 29",
		"28 Tishrei 5759,Pesachim 30",
		"29 Tishrei 5759,Pesachim 31",
		"30 Tishrei 5759,Pesachim 32",
		"1 Cheshvan 5759,Pesachim 33",
		"2 Cheshvan 5759,Pesachim 34",
		"3 Cheshvan 5759,Pesachim 35",
		"4 Cheshvan 5759,Pesachim 36",
		"5 Cheshvan 5759,Pesachim 37",
		"6 Cheshvan 5759,Pesachim 38",
		"7 Cheshvan 5759,Pesachim 39",
		"8 Cheshvan 5759,Pesachim 40",
		"9 Cheshvan 5759,Pesachim 41",
		"10 Cheshvan 5759,Pesachim 42",
		"11 Cheshvan 5759,Pesachim 43",
		"12 Cheshvan 5759,Pesachim 44",
		"13 Cheshvan 5759,Pesachim 45",
		"14 Cheshvan 5759,Pesachim 46",
		"15 Cheshvan 5759,Pesachim 47",
		"16 Cheshvan 5759,Pesachim 48",
		"17 Cheshvan 5759,Pesachim 49",
		"18 Cheshvan 5759,Pesachim 50",
		"19 Cheshvan 5759,Pesachim 51",
		"20 Cheshvan 5759,Pesachim 52",
		"21 Cheshvan 5759,Pesachim 53",
		"22 Cheshvan 5759,Pesachim 54",
		"23 Cheshvan 5759,Pesachim 55",
		"24 Cheshvan 5759,Pesachim 56",
		"25 Cheshvan 5759,Pesachim 57",
		"26 Cheshvan 5759,Pesachim 58",
		"27 Cheshvan 5759,Pesachim 59",
		"28 Cheshvan 5759,Pesachim 60",
		"29 Cheshvan 5759,Pesachim 61",
		"30 Cheshvan 5759,Pesachim 62",
		"1 Kislev 5759,Pesachim 63",
		"2 Kislev 5759,Pesachim 64",
		"3 Kislev 5759,Pesachim 65",
		"4 Kislev 5759,Pesachim 66",
		"5 Kislev 5759,Pesachim 67",
		"6 Kislev 5759,Pesachim 68",
		"7 Kislev 5759,Pesachim 69",
		"8 Kislev 5759,Pesachim 70",
		"9 Kislev 5759,Pesachim 71",
		"10 Kislev 5759,Beitzah 1",
		"11 Kislev 5759,Beitzah 2",
		"12 Kislev 5759,Beitzah 3",
		"13 Kislev 5759,Beitzah 4",
		"14 Kislev 5759,Beitzah 5",
		"15 Kislev 5759,Beitzah 6",
		"16 Kislev 5759,Beitzah 7",
		"17 Kislev 5759,Beitzah 8",
		"18 Kislev 5759,Beitzah 9",
		"19 Kislev 5759,Beitzah 10",
		"20 Kislev 5759,Beitzah 11",
		"21 Kislev 5759,Beitzah 12",
		"22 Kislev 5759,Beitzah 13",
		"23 Kislev 5759,Beitzah 14",
		"24 Kislev 5759,Beitzah 15",
		"25 Kislev 5759,Beitzah 16",
		"26 Kislev 5759,Beitzah 17",
		"27 Kislev 5759,Beitzah 18",
		"28 Kislev 5759,Beitzah 19",
		"29 Kislev 5759,Beitzah 20",
		"30 Kislev 5759,Beitzah 21",
		"1 Tevet 5759,Beitzah 22",
		"2 Tevet 5759,Rosh Hashanah 1",
		"3 Tevet 5759,Rosh Hashanah 2",
		"4 Tevet 5759,Rosh Hashanah 3",
		"5 Tevet 5759,Rosh Hashanah 4",
		"6 Tevet 5759,Rosh Hashanah 5",
		"7 Tevet 5759,Rosh Hashanah 6",
		"8 Tevet 5759,Rosh Hashanah 7",
		"9 Tevet 5759,Rosh Hashanah 8",
		"10 Tevet 5759,Rosh Hashanah 9",
		"11 Tevet 5759,Rosh Hashanah 10",
		"12 Tevet 5759,Rosh Hashanah 11",
		"13 Tevet 5759,Rosh Hashanah 12",
		"14 Tevet 5759,Rosh Hashanah 13",
		"15 Tevet 5759,Rosh Hashanah 14",
		"16 Tevet 5759,Rosh Hashanah 15",
		"17 Tevet 5759,Rosh Hashanah 16",
		"18 Tevet 5759,Rosh Hashanah 17",
		"19 Tevet 5759,Rosh Hashanah 18",
		"20 Tevet 5759,Rosh Hashanah 19",
		"21 Tevet 5759,Rosh Hashanah 20",
		"22 Tevet 5759,Rosh Hashanah 21",
		"23 Tevet 5759,Rosh Hashanah 22",
		"24 Tevet 5759,Yoma 1",
		"25 Tevet 5759,Yoma 2",
		"26 Tevet 5759,Yoma 3",
		"27 Tevet 5759,Yoma 4",
		"28 Tevet 5759,Yoma 5",
		"29 Tevet 5759,Yoma 6",
		"1 Sh'vat 5759,Yoma 7",
		"2 Sh'vat 5759,Yoma 8",
		"3 Sh'vat 5759,Yoma 9",
		"4 Sh'vat 5759,Yoma 10",
		"5 Sh'vat 5759,Yoma 11",
		"6 Sh'vat 5759,Yoma 12",
		"7 Sh'vat 5759,Yoma 13",
		"8 Sh'vat 5759,Yoma 14",
		"9 Sh'vat 5759,Yoma 15",
		"10 Sh'vat 5759,Yoma 16",
		"11 Sh'vat 5759,Yoma 17",
		"12 Sh'vat 5759,Yoma 18",
		"13 Sh'vat 5759,Yoma 19",
		"14 Sh'vat 5759,Yoma 20",
		"15 Sh'vat 5759,Yoma 21",
		"16 Sh'vat 5759,Yoma 22",
		"17 Sh'vat 5759,Yoma 23",
		"18 Sh'vat 5759,Yoma 24",
		"19 Sh'vat 5759,Yoma 25",
		"20 Sh'vat 5759,Yoma 26",
		"21 Sh'vat 5759,Yoma 27",
		"22 Sh'vat 5759,Yoma 28",
		"23 Sh'vat 5759,Yoma 29",
		"24 Sh'vat 5759,Yoma 30",
		"25 Sh'vat 5759,Yoma 31",
		"26 Sh'vat 5759,Yoma 32",
		"27 Sh'vat 5759,Yoma 33",
		"28 Sh'vat 5759,Yoma 34",
		"29 Sh'vat 5759,Yoma 35",
		"30 Sh'vat 5759,Yoma 36",
		"1 Adar 5759,Yoma 37",
		"2 Adar 5759,Yoma 38",
		"3 Adar 5759,Yoma 39",
		"4 Adar 5759,Yoma 40",
		"5 Adar 5759,Yoma 41",
		"6 Adar 5759,Yoma 42",
		"7 Adar 5759,Sukkah 1",
		"8 Adar 5759,Sukkah 2",
		"9 Adar 5759,Sukkah 3",
		"10 Adar 5759,Sukkah 4",
		"11 Adar 5759,Sukkah 5",
		"12 Adar 5759,Sukkah 6",
		"13 Adar 5759,Sukkah 7",
		"14 Adar 5759,Sukkah 8",
		"15 Adar 5759,Sukkah 9",
		"16 Adar 5759,Sukkah 10",
		"17 Adar 5759,Sukkah 11",
		"18 Adar 5759,Sukkah 12",
		"19 Adar 5759,Sukkah 13",
		"20 Adar 5759,Sukkah 14",
		"21 Adar 5759,Sukkah 15",
		"22 Adar 5759,Sukkah 16",
		"23 Adar 5759,Sukkah 17",
		"24 Adar 5759,Sukkah 18",
		"25 Adar 5759,Sukkah 19",
		"26 Adar 5759,Sukkah 20",
		"27 Adar 5759,Sukkah 21",
		"28 Adar 5759,Sukkah 22",
		"29 Adar 5759,Sukkah 23",
		"1 Nisan 5759,Sukkah 24",
		"2 Nisan 5759,Sukkah 25",
		"3 Nisan 5759,Sukkah 26",
		"4 Nisan 5759,Taanit 1",
		"5 Nisan 5759,Taanit 2",
		"6 Nisan 5759,Taanit 3",
		"7 Nisan 5759,Taanit 4",
		"8 Nisan 5759,Taanit 5",
		"9 Nisan 5759,Taanit 6",
		"10 Nisan 5759,Taanit 7",
		"11 Nisan 5759,Taanit 8",
		"12 Nisan 5759,Taanit 9",
		"13 Nisan 5759,Taanit 10",
		"14 Nisan 5759,Taanit 11",
		"15 Nisan 5759,Taanit 12",
		"16 Nisan 5759,Taanit 13",
		"17 Nisan 5759,Taanit 14",
		"18 Nisan 5759,Taanit 15",
		"19 Nisan 5759,Taanit 16",
		"20 Nisan 5759,Taanit 17",
		"21 Nisan 5759,Taanit 18",
		"22 Nisan 5759,Taanit 19",
		"23 Nisan 5759,Taanit 20",
		"24 Nisan 5759,Taanit 21",
		"25 Nisan 5759,Taanit 22",
		"26 Nisan 5759,Taanit 23",
		"27 Nisan 5759,Taanit 24",
		"28 Nisan 5759,Taanit 25",
		"29 Nisan 5759,Taanit 26",
		"30 Nisan 5759,Shekalim 1",
		"1 Iyyar 5759,Shekalim 2",
		"2 Iyyar 5759,Shekalim 3",
		"3 Iyyar 5759,Shekalim 4",
		"4 Iyyar 5759,Shekalim 5",
		"5 Iyyar 5759,Shekalim 6",
		"6 Iyyar 5759,Shekalim 7",
		"7 Iyyar 5759,Shekalim 8",
		"8 Iyyar 5759,Shekalim 9",
		"9 Iyyar 5759,Shekalim 10",
		"10 Iyyar 5759,Shekalim 11",
		"11 Iyyar 5759,Shekalim 12",
		"12 Iyyar 5759,Shekalim 13",
		"13 Iyyar 5759,Shekalim 14",
		"14 Iyyar 5759,Shekalim 15",
		"15 Iyyar 5759,Shekalim 16",
		"16 Iyyar 5759,Shekalim 17",
		"17 Iyyar 5759,Shekalim 18",
		"18 Iyyar 5759,Shekalim 19",
		"19 Iyyar 5759,Shekalim 20",
		"20 Iyyar 5759,Shekalim 21",
		"21 Iyyar 5759,Shekalim 22",
		"22 Iyyar 5759,Shekalim 23",
		"23 Iyyar 5759,Shekalim 24",
		"24 Iyyar 5759,Shekalim 25",
		"25 Iyyar 5759,Shekalim 26",
		"26 Iyyar 5759,Shekalim 27",
		"27 Iyyar 5759,Shekalim 28",
		"28 Iyyar 5759,Shekalim 29",
		"29 Iyyar 5759,Shekalim 30",
		"1 Sivan 5759,Shekalim 31",
		"2 Sivan 5759,Shekalim 32",
		"3 Sivan 5759,Shekalim 33",
		"4 Sivan 5759,Megillah 1",
		"5 Sivan 5759,Megillah 2",
		"6 Sivan 5759,Megillah 3",
		"7 Sivan 5759,Megillah 4",
		"8 Sivan 5759,Megillah 5",
		"9 Sivan 5759,Megillah 6",
		"10 Sivan 5759,Megillah 7",
		"11 Sivan 5759,Megillah 8",
		"12 Sivan 5759,Megillah 9",
		"13 Sivan 5759,Megillah 10",
		"14 Sivan 5759,Megillah 11",
		"15 Sivan 5759,Megillah 12",
		"16 Sivan 5759,Megillah 13",
		"17 Sivan 5759,Megillah 14",
		"18 Sivan 5759,Megillah 15",
		"19 Sivan 5759,Megillah 16",
		"20 Sivan 5759,Megillah 17",
		"21 Sivan 5759,Megillah 18",
		"22 Sivan 5759,Megillah 19",
		"23 Sivan 5759,Megillah 20",
		"24 Sivan 5759,Megillah 21",
		"25 Sivan 5759,Megillah 22",
		"26 Sivan 5759,Megillah 23",
		"27 Sivan 5759,Megillah 24",
		"28 Sivan 5759,Megillah 25",
		"29 Sivan 5759,Megillah 26",
		"30 Sivan 5759,Megillah 27",
		"1 Tamuz 5759,Megillah 28",
		"2 Tamuz 5759,Megillah 29",
		"3 Tamuz 5759,Megillah 30",
		"4 Tamuz 5759,Megillah 31",
		"5 Tamuz 5759,Megillah 32",
		"6 Tamuz 5759,Megillah 33",
		"7 Tamuz 5759,Megillah 34",
		"8 Tamuz 5759,Chagigah 1",
		"9 Tamuz 5759,Chagigah 2",
		"10 Tamuz 5759,Chagigah 3",
		"11 Tamuz 5759,Chagigah 4",
		"12 Tamuz 5759,Chagigah 5",
		"13 Tamuz 5759,Chagigah 6",
		"14 Tamuz 5759,Chagigah 7",
		"15 Tamuz 5759,Chagigah 8",
		"16 Tamuz 5759,Chagigah 9",
		"17 Tamuz 5759,Chagigah 10",
		"18 Tamuz 5759,Chagigah 11",
		"19 Tamuz 5759,Chagigah 12",
		"20 Tamuz 5759,Chagigah 13",
		"21 Tamuz 5759,Chagigah 14",
		"22 Tamuz 5759,Chagigah 15",
		"23 Tamuz 5759,Chagigah 16",
		"24 Tamuz 5759,Chagigah 17",
		"25 Tamuz 5759,Chagigah 18",
		"26 Tamuz 5759,Chagigah 19",
		"27 Tamuz 5759,Chagigah 20",
		"28 Tamuz 5759,Chagigah 21",
		"29 Tamuz 5759,Chagigah 22",
		"1 Av 5759,Moed Katan 1",
		"2 Av 5759,Moed Katan 2",
		"3 Av 5759,Moed Katan 3",
		"4 Av 5759,Moed Katan 4",
		"5 Av 5759,Moed Katan 5",
		"6 Av 5759,Moed Katan 6",
		"7 Av 5759,Moed Katan 7",
		"8 Av 5759,Moed Katan 8",
		"9 Av 5759,%!Daf(,0)",
		"10 Av 5759,Moed Katan 9",
		"11 Av 5759,Moed Katan 10",
		"12 Av 5759,Moed Katan 11",
		"13 Av 5759,Moed Katan 12",
		"14 Av 5759,Moed Katan 13",
		"15 Av 5759,Moed Katan 14",
		"16 Av 5759,Moed Katan 15",
		"17 Av 5759,Moed Katan 16",
		"18 Av 5759,Moed Katan 17",
		"19 Av 5759,Moed Katan 18",
		"20 Av 5759,Moed Katan 19",
		"21 Av 5759,Yevamot 1",
		"22 Av 5759,Yevamot 2",
		"23 Av 5759,Yevamot 3",
		"24 Av 5759,Yevamot 4",
		"25 Av 5759,Yevamot 5",
		"26 Av 5759,Yevamot 6",
		"27 Av 5759,Yevamot 7",
		"28 Av 5759,Yevamot 8",
		"29 Av 5759,Yevamot 9",
		"30 Av 5759,Yevamot 10",
		"1 Elul 5759,Yevamot 11",
		"2 Elul 5759,Yevamot 12",
		"3 Elul 5759,Yevamot 13",
		"4 Elul 5759,Yevamot 14",
		"5 Elul 5759,Yevamot 15",
		"6 Elul 5759,Yevamot 16",
		"7 Elul 5759,Yevamot 17",
		"8 Elul 5759,Yevamot 18",
		"9 Elul 5759,Yevamot 19",
		"10 Elul 5759,Yevamot 20",
		"11 Elul 5759,Yevamot 21",
		"12 Elul 5759,Yevamot 22",
		"13 Elul 5759,Yevamot 23",
		"14 Elul 5759,Yevamot 24",
		"15 Elul 5759,Yevamot 25",
		"16 Elul 5759,Yevamot 26",
		"17 Elul 5759,Yevamot 27",
		"18 Elul 5759,Yevamot 28",
		"19 Elul 5759,Yevamot 29",
		"20 Elul 5759,Yevamot 30",
		"21 Elul 5759,Yevamot 31",
		"22 Elul 5759,Yevamot 32",
		"23 Elul 5759,Yevamot 33",
		"24 Elul 5759,Yevamot 34",
		"25 Elul 5759,Yevamot 35",
		"26 Elul 5759,Yevamot 36",
		"27 Elul 5759,Yevamot 37",
		"28 Elul 5759,Yevamot 38",
		"29 Elul 5759,Yevamot 39",
		"1 Tishrei 5760,Yevamot 40",
		"2 Tishrei 5760,Yevamot 41",
		"3 Tishrei 5760,Yevamot 42",
		"4 Tishrei 5760,Yevamot 43",
		"5 Tishrei 5760,Yevamot 44",
		"6 Tishrei 5760,Yevamot 45",
		"7 Tishrei 5760,Yevamot 46",
		"8 Tishrei 5760,Yevamot 47",
		"9 Tishrei 5760,Yevamot 48",
		"10 Tishrei 5760,%!Daf(,0)",
		"11 Tishrei 5760,Yevamot 49",
		"12 Tishrei 5760,Yevamot 50",
		"13 Tishrei 5760,Yevamot 51",
		"14 Tishrei 5760,Yevamot 52",
		"15 Tishrei 5760,Yevamot 53",
		"16 Tishrei 5760,Yevamot 54",
		"17 Tishrei 5760,Yevamot 55",
		"18 Tishrei 5760,Yevamot 56",
		"19 Tishrei 5760,Yevamot 57",
		"20 Tishrei 5760,Yevamot 58",
		"21 Tishrei 5760,Yevamot 59",
		"22 Tishrei 5760,Yevamot 60",
		"23 Tishrei 5760,Yevamot 61",
		"24 Tishrei 5760,Yevamot 62",
		"25 Tishrei 5760,Yevamot 63",
		"26 Tishrei 5760,Yevamot 64",
		"27 Tishrei 5760,Yevamot 65",
		"28 Tishrei 5760,Yevamot 66",
		"29 Tishrei 5760,Yevamot 67",
		"30 Tishrei 5760,Yevamot 68",
		"1 Cheshvan 5760,Yevamot 69",
		"2 Cheshvan 5760,Yevamot 70",
		"3 Cheshvan 5760,Yevamot 71",
		"4 Cheshvan 5760,Yevamot 72",
		"5 Cheshvan 5760,Yevamot 73",
		"6 Cheshvan 5760,Yevamot 74",
		"7 Cheshvan 5760,Yevamot 75",
		"8 Cheshvan 5760,Yevamot 76",
		"9 Cheshvan 5760,Yevamot 77",
		"10 Cheshvan 5760,Yevamot 78",
		"11 Cheshvan 5760,Yevamot 79",
		"12 Cheshvan 5760,Yevamot 80",
		"13 Cheshvan 5760,Yevamot 81",
		"14 Cheshvan 5760,Yevamot 82",
		"15 Cheshvan 5760,Yevamot 83",
		"16 Cheshvan 5760,Yevamot 84",
		"17 Cheshvan 5760,Yevamot 85",
		"18 Cheshvan 5760,Ketubot 1",
		"19 Cheshvan 5760,Ketubot 2",
		"20 Cheshvan 5760,Ketubot 3",
		"21 Cheshvan 5760,Ketubot 4",
		"22 Cheshvan 5760,Ketubot 5",
		"23 Cheshvan 5760,Ketubot 6",
		"24 Cheshvan 5760,Ketubot 7",
		"25 Cheshvan 5760,Ketubot 8",
		"26 Cheshvan 5760,Ketubot 9",
		"27 Cheshvan 5760,Ketubot 10",
		"28 Cheshvan 5760,Ketubot 11",
		"29 Cheshvan 5760,Ketubot 12",
		"30 Cheshvan 5760,Ketubot 13",
		"1 Kislev 5760,Ketubot 14",
		"2 Kislev 5760,Ketubot 15",
		"3 Kislev 5760,Ketubot 16",
		"4 Kislev 5760,Ketubot 17",
		"5 Kislev 5760,Ketubot 18",
		"6 Kislev 5760,Ketubot 19",
		"7 Kislev 5760,Ketubot 20",
		"8 Kislev 5760,Ketubot 21",
		"9 Kislev 5760,Ketubot 22",
		"10 Kislev 5760,Ketubot 23",
		"11 Kislev 5760,Ketubot 24",
		"12 Kislev 5760,Ketubot 25",
		"13 Kislev 5760,Ketubot 26",
		"14 Kislev 5760,Ketubot 27",
		"15 Kislev 5760,Ketubot 28",
		"16 Kislev 5760,Ketubot 29",
		"17 Kislev 5760,Ketubot 30",
		"18 Kislev 5760,Ketubot 31",
		"19 Kislev 5760,Ketubot 32",
		"20 Kislev 5760,Ketubot 33",
		"21 Kislev 5760,Ketubot 34",
		"22 Kislev 5760,Ketubot 35",
		"23 Kislev 5760,Ketubot 36",
		"24 Kislev 5760,Ketubot 37",
		"25 Kislev 5760,Ketubot 38",
		"26 Kislev 5760,Ketubot 39",
		"27 Kislev 5760,Ketubot 40",
		"28 Kislev 5760,Ketubot 41",
		"29 Kislev 5760,Ketubot 42",
		"30 Kislev 5760,Ketubot 43",
		"1 Tevet 5760,Ketubot 44",
		"2 Tevet 5760,Ketubot 45",
		"3 Tevet 5760,Ketubot 46",
		"4 Tevet 5760,Ketubot 47",
		"5 Tevet 5760,Ketubot 48",
		"6 Tevet 5760,Ketubot 49",
		"7 Tevet 5760,Ketubot 50",
		"8 Tevet 5760,Ketubot 51",
		"9 Tevet 5760,Ketubot 52",
		"10 Tevet 5760,Ketubot 53",
		"11 Tevet 5760,Ketubot 54",
		"12 Tevet 5760,Ketubot 55",
		"13 Tevet 5760,Ketubot 56",
		"14 Tevet 5760,Ketubot 57",
		"15 Tevet 5760,Ketubot 58",
		"16 Tevet 5760,Ketubot 59",
		"17 Tevet 5760,Ketubot 60",
		"18 Tevet 5760,Ketubot 61",
		"19 Tevet 5760,Ketubot 62",
		"20 Tevet 5760,Ketubot 63",
		"21 Tevet 5760,Ketubot 64",
		"22 Tevet 5760,Ketubot 65",
		"23 Tevet 5760,Ketubot 66",
		"24 Tevet 5760,Ketubot 67",
		"25 Tevet 5760,Ketubot 68",
		"26 Tevet 5760,Ketubot 69",
		"27 Tevet 5760,Ketubot 70",
		"28 Tevet 5760,Ketubot 71",
		"29 Tevet 5760,Ketubot 72",
		"1 Sh'vat 5760,Sotah 1",
		"2 Sh'vat 5760,Sotah 2",
		"3 Sh'vat 5760,Sotah 3",
		"4 Sh'vat 5760,Sotah 4",
		"5 Sh'vat 5760,Sotah 5",
		"6 Sh'vat 5760,Sotah 6",
		"7 Sh'vat 5760,Sotah 7",
		"8 Sh'vat 5760,Sotah 8",
		"9 Sh'vat 5760,Sotah 9",
		"10 Sh'vat 5760,Sotah 10",
		"11 Sh'vat 5760,Sotah 11",
		"12 Sh'vat 5760,Sotah 12",
		"13 Sh'vat 5760,Sotah 13",
		"14 Sh'vat 5760,Sotah 14",
		"15 Sh'vat 5760,Sotah 15",
		"16 Sh'vat 5760,Sotah 16",
		"17 Sh'vat 5760,Sotah 17",
		"18 Sh'vat 5760,Sotah 18",
		"19 Sh'vat 5760,Sotah 19",
		"20 Sh'vat 5760,Sotah 20",
		"21 Sh'vat 5760,Sotah 21",
		"22 Sh'vat 5760,Sotah 22",
		"23 Sh'vat 5760,Sotah 23",
		"24 Sh'vat 5760,Sotah 24",
		"25 Sh'vat 5760,Sotah 25",
		"26 Sh'vat 5760,Sotah 26",
		"27 Sh'vat 5760,Sotah 27",
		"28 Sh'vat 5760,Sotah 28",
		"29 Sh'vat 5760,Sotah 29",
		"30 Sh'vat 5760,Sotah 30",
		"1 Adar I 5760,Sotah 31",
		"2 Adar I 5760,Sotah 32",
		"3 Adar I 5760,Sotah 33",
		"4 Adar I 5760,Sotah 34",
		"5 Adar I 5760,Sotah 35",
		"6 Adar I 5760,Sotah 36",
		"7 Adar I 5760,Sotah 37",
		"8 Adar I 5760,Sotah 38",
		"9 Adar I 5760,Sotah 39",
		"10 Adar I 5760,Sotah 40",
		"11 Adar I 5760,Sotah 41",
		"12 Adar I 5760,Sotah 42",
		"13 Adar I 5760,Sotah 43",
		"14 Adar I 5760,Sotah 44",
		"15 Adar I 5760,Sotah 45",
		"16 Adar I 5760,Sotah 46",
		"17 Adar I 5760,Sotah 47",
		"18 Adar I 5760,Nedarim 1",
		"19 Adar I 5760,Nedarim 2",
		"20 Adar I 5760,Nedarim 3",
		"21 Adar I 5760,Nedarim 4",
		"22 Adar I 5760,Nedarim 5",
		"23 Adar I 5760,Nedarim 6",
		"24 Adar I 5760,Nedarim 7",
		"25 Adar I 5760,Nedarim 8",
		"26 Adar I 5760,Nedarim 9",
		"27 Adar I 5760,Nedarim 10",
		"28 Adar I 5760,Nedarim 11",
		"29 Adar I 5760,Nedarim 12",
		"30 Adar I 5760,Nedarim 13",
		"1 Adar II 5760,Nedarim 14",
		"2 Adar II 5760,Nedarim 15",
		"3 Adar II 5760,Nedarim 16",
		"4 Adar II 5760,Nedarim 17",
		"5 Adar II 5760,Nedarim 18",
		"6 Adar II 5760,Nedarim 19",
		"7 Adar II 5760,Nedarim 20",
		"8 Adar II 5760,Nedarim 21",
		"9 Adar II 5760,Nedarim 22",
		"10 Adar II 5760,Nedarim 23",
		"11 Adar II 5760,Nedarim 24",
		"12 Adar II 5760,Nedarim 25",
		"13 Adar II 5760,Nedarim 26",
		"14 Adar II 5760,Nedarim 27",
		"15 Adar II 5760,Nedarim 28",
		"16 Adar II 5760,Nedarim 29",
		"17 Adar II 5760,Nedarim 30",
		"18 Adar II 5760,Nedarim 31",
		"19 Adar II 5760,Nedarim 32",
		"20 Adar II 5760,Nedarim 33",
		"21 Adar II 5760,Nedarim 34",
		"22 Adar II 5760,Nedarim 35",
		"23 Adar II 5760,Nedarim 36",
		"24 Adar II 5760,Nedarim 37",
		"25 Adar II 5760,Nedarim 38",
		"26 Adar II 5760,Nedarim 39",
		"27 Adar II 5760,Nedarim 40",
		"28 Adar II 5760,Nazir 1",
		"29 Adar II 5760,Nazir 2",
		"1 Nisan 5760,Nazir 3",
		"2 Nisan 5760,Nazir 4",
		"3 Nisan 5760,Nazir 5",
		"4 Nisan 5760,Nazir 6",
		"5 Nisan 5760,Nazir 7",
		"6 Nisan 5760,Nazir 8",
		"7 Nisan 5760,Nazir 9",
		"8 Nisan 5760,Nazir 10",
		"9 Nisan 5760,Nazir 11",
		"10 Nisan 5760,Nazir 12",
		"11 Nisan 5760,Nazir 13",
		"12 Nisan 5760,Nazir 14",
		"13 Nisan 5760,Nazir 15",
		"14 Nisan 5760,Nazir 16",
		"15 Nisan 5760,Nazir 17",
		"16 Nisan 5760,Nazir 18",
		"17 Nisan 5760,Nazir 19",
		"18 Nisan 5760,Nazir 20",
		"19 Nisan 5760,Nazir 21",
		"20 Nisan 5760,Nazir 22",
		"21 Nisan 5760,Nazir 23",
		"22 Nisan 5760,Nazir 24",
		"23 Nisan 5760,Nazir 25",
		"24 Nisan 5760,Nazir 26",
		"25 Nisan 5760,Nazir 27",
		"26 Nisan 5760,Nazir 28",
		"27 Nisan 5760,Nazir 29",
		"28 Nisan 5760,Nazir 30",
		"29 Nisan 5760,Nazir 31",
		"30 Nisan 5760,Nazir 32",
		"1 Iyyar 5760,Nazir 33",
		"2 Iyyar 5760,Nazir 34",
		"3 Iyyar 5760,Nazir 35",
		"4 Iyyar 5760,Nazir 36",
		"5 Iyyar 5760,Nazir 37",
		"6 Iyyar 5760,Nazir 38",
		"7 Iyyar 5760,Nazir 39",
		"8 Iyyar 5760,Nazir 40",
		"9 Iyyar 5760,Nazir 41",
		"10 Iyyar 5760,Nazir 42",
		"11 Iyyar 5760,Nazir 43",
		"12 Iyyar 5760,Nazir 44",
		"13 Iyyar 5760,Nazir 45",
		"14 Iyyar 5760,Nazir 46",
		"15 Iyyar 5760,Nazir 47",
		"16 Iyyar 5760,Gittin 1",
		"17 Iyyar 5760,Gittin 2",
		"18 Iyyar 5760,Gittin 3",
		"19 Iyyar 5760,Gittin 4",
		"20 Iyyar 5760,Gittin 5",
		"21 Iyyar 5760,Gittin 6",
		"22 Iyyar 5760,Gittin 7",
		"23 Iyyar 5760,Gittin 8",
		"24 Iyyar 5760,Gittin 9",
		"25 Iyyar 5760,Gittin 10",
		"26 Iyyar 5760,Gittin 11",
		"27 Iyyar 5760,Gittin 12",
		"28 Iyyar 5760,Gittin 13",
		"29 Iyyar 5760,Gittin 14",
		"1 Sivan 5760,Gittin 15",
		"2 Sivan 5760,Gittin 16",
		"3 Sivan 5760,Gittin 17",
		"4 Sivan 5760,Gittin 18",
		"5 Sivan 5760,Gittin 19",
		"6 Sivan 5760,Gittin 20",
		"7 Sivan 5760,Gittin 21",
		"8 Sivan 5760,Gittin 22",
		"9 Sivan 5760,Gittin 23",
		"10 Sivan 5760,Gittin 24",
		"11 Sivan 5760,Gittin 25",
		"12 Sivan 5760,Gittin 26",
		"13 Sivan 5760,Gittin 27",
		"14 Sivan 5760,Gittin 28",
		"15 Sivan 5760,Gittin 29",
		"16 Sivan 5760,Gittin 30",
		"17 Sivan 5760,Gittin 31",
		"18 Sivan 5760,Gittin 32",
		"19 Sivan 5760,Gittin 33",
		"20 Sivan 5760,Gittin 34",
		"21 Sivan 5760,Gittin 35",
		"22 Sivan 5760,Gittin 36",
		"23 Sivan 5760,Gittin 37",
		"24 Sivan 5760,Gittin 38",
		"25 Sivan 5760,Gittin 39",
		"26 Sivan 5760,Gittin 40",
		"27 Sivan 5760,Gittin 41",
		"28 Sivan 5760,Gittin 42",
		"29 Sivan 5760,Gittin 43",
		"30 Sivan 5760,Gittin 44",
		"1 Tamuz 5760,Gittin 45",
		"2 Tamuz 5760,Gittin 46",
		"3 Tamuz 5760,Gittin 47",
		"4 Tamuz 5760,Gittin 48",
		"5 Tamuz 5760,Gittin 49",
		"6 Tamuz 5760,Gittin 50",
		"7 Tamuz 5760,Gittin 51",
		"8 Tamuz 5760,Gittin 52",
		"9 Tamuz 5760,Gittin 53",
		"10 Tamuz 5760,Gittin 54",
		"11 Tamuz 5760,Kiddushin 1",
		"12 Tamuz 5760,Kiddushin 2",
		"13 Tamuz 5760,Kiddushin 3",
		"14 Tamuz 5760,Kiddushin 4",
		"15 Tamuz 5760,Kiddushin 5",
		"16 Tamuz 5760,Kiddushin 6",
		"17 Tamuz 5760,Kiddushin 7",
		"18 Tamuz 5760,Kiddushin 8",
		"19 Tamuz 5760,Kiddushin 9",
		"20 Tamuz 5760,Kiddushin 10",
		"21 Tamuz 5760,Kiddushin 11",
		"22 Tamuz 5760,Kiddushin 12",
		"23 Tamuz 5760,Kiddushin 13",
		"24 Tamuz 5760,Kiddushin 14",
		"25 Tamuz 5760,Kiddushin 15",
		"26 Tamuz 5760,Kiddushin 16",
		"27 Tamuz 5760,Kiddushin 17",
		"28 Tamuz 5760,Kiddushin 18",
		"29 Tamuz 5760,Kiddushin 19",
		"1 Av 5760,Kiddushin 20",
		"2 Av 5760,Kiddushin 21",
		"3 Av 5760,Kiddushin 22",
		"4 Av 5760,Kiddushin 23",
		"5 Av 5760,Kiddushin 24",
		"6 Av 5760,Kiddushin 25",
		"7 Av 5760,Kiddushin 26",
		"8 Av 5760,Kiddushin 27",
		"9 Av 5760,%!Daf(,0)",
		"10 Av 5760,Kiddushin 28",
		"11 Av 5760,Kiddushin 29",
		"12 Av 5760,Kiddushin 30",
		"13 Av 5760,Kiddushin 31",
		"14 Av 5760,Kiddushin 32",
		"15 Av 5760,Kiddushin 33",
		"16 Av 5760,Kiddushin 34",
		"17 Av 5760,Kiddushin 35",
		"18 Av 5760,Kiddushin 36",
		"19 Av 5760,Kiddushin 37",
		"20 Av 5760,Kiddushin 38",
		"21 Av 5760,Kiddushin 39",
		"22 Av 5760,Kiddushin 40",
		"23 Av 5760,Kiddushin 41",
		"24 Av 5760,Kiddushin 42",
		"25 Av 5760,Kiddushin 43",
		"26 Av 5760,Kiddushin 44",
		"27 Av 5760,Kiddushin 45",
		"28 Av 5760,Kiddushin 46",
		"29 Av 5760,Kiddushin 47",
		"30 Av 5760,Kiddushin 48",
		"1 Elul 5760,Bava Kamma 1",
		"2 Elul 5760,Bava Kamma 2",
		"3 Elul 5760,Bava Kamma 3",
		"4 Elul 5760,Bava Kamma 4",
		"5 Elul 5760,Bava Kamma 5",
		"6 Elul 5760,Bava Kamma 6",
		"7 Elul 5760,Bava Kamma 7",
		"8 Elul 5760,Bava Kamma 8",
		"9 Elul 5760,Bava Kamma 9",
		"10 Elul 5760,Bava Kamma 10",
		"11 Elul 5760,Bava Kamma 11",
		"12 Elul 5760,Bava Kamma 12",
		"13 Elul 5760,Bava Kamma 13",
		"14 Elul 5760,Bava Kamma 14",
		"15 Elul 5760,Bava Kamma 15",
		"16 Elul 5760,Bava Kamma 16",
		"17 Elul 5760,Bava Kamma 17",
		"18 Elul 5760,Bava Kamma 18",
		"19 Elul 5760,Bava Kamma 19",
		"20 Elul 5760,Bava Kamma 20",
		"21 Elul 5760,Bava Kamma 21",
		"22 Elul 5760,Bava Kamma 22",
		"23 Elul 5760,Bava Kamma 23",
		"24 Elul 5760,Bava Kamma 24",
		"25 Elul 5760,Bava Kamma 25",
		"26 Elul 5760,Bava Kamma 26",
		"27 Elul 5760,Bava Kamma 27",
		"28 Elul 5760,Bava Kamma 28",
		"29 Elul 5760,Bava Kamma 29",
		"1 Tishrei 5761,Bava Kamma 30",
		"2 Tishrei 5761,Bava Kamma 31",
		"3 Tishrei 5761,Bava Kamma 32",
		"4 Tishrei 5761,Bava Kamma 33",
		"5 Tishrei 5761,Bava Kamma 34",
		"6 Tishrei 5761,Bava Kamma 35",
		"7 Tishrei 5761,Bava Kamma 36",
		"8 Tishrei 5761,Bava Kamma 37",
		"9 Tishrei 5761,Bava Kamma 38",
		"10 Tishrei 5761,%!Daf(,0)",
		"11 Tishrei 5761,Bava Kamma 39",
		"12 Tishrei 5761,Bava Kamma 40",
		"13 Tishrei 5761,Bava Kamma 41",
		"14 Tishrei 5761,Bava Kamma 42",
		"15 Tishrei 5761,Bava Kamma 43",
		"16 Tishrei 5761,Bava Kamma 44",
		"17 Tishrei 5761,Bava Metzia 1",
		"18 Tishrei 5761,Bava Metzia 2",
		"19 Tishrei 5761,Bava Metzia 3",
		"20 Tishrei 5761,Bava Metzia 4",
		"21 Tishrei 5761,Bava Metzia 5",
		"22 Tishrei 5761,Bava Metzia 6",
		"23 Tishrei 5761,Bava Metzia 7",
		"24 Tishrei 5761,Bava Metzia 8",
		"25 Tishrei 5761,Bava Metzia 9",
		"26 Tishrei 5761,Bava Metzia 10",
		"27 Tishrei 5761,Bava Metzia 11",
		"28 Tishrei 5761,Bava Metzia 12",
		"29 Tishrei 5761,Bava Metzia 13",
		"30 Tishrei 5761,Bava Metzia 14",
		"1 Cheshvan 5761,Bava Metzia 15",
		"2 Cheshvan 5761,Bava Metzia 16",
		"3 Cheshvan 5761,Bava Metzia 17",
		"4 Cheshvan 5761,Bava Metzia 18",
		"5 Cheshvan 5761,Bava Metzia 19",
		"6 Cheshvan 5761,Bava Metzia 20",
		"7 Cheshvan 5761,Bava Metzia 21",
		"8 Cheshvan 5761,Bava Metzia 22",
		"9 Cheshvan 5761,Bava Metzia 23",
		"10 Cheshvan 5761,Bava Metzia 24",
		"11 Cheshvan 5761,Bava Metzia 25",
		"12 Cheshvan 5761,Bava Metzia 26",
		"13 Cheshvan 5761,Bava Metzia 27",
		"14 Cheshvan 5761,Bava Metzia 28",
		"15 Cheshvan 5761,Bava Metzia 29",
		"16 Cheshvan 5761,Bava Metzia 30",
		"17 Cheshvan 5761,Bava Metzia 31",
		"18 Cheshvan 5761,Bava Metzia 32",
		"19 Cheshvan 5761,Bava Metzia 33",
		"20 Cheshvan 5761,Bava Metzia 34",
		"21 Cheshvan 5761,Bava Metzia 35",
		"22 Cheshvan 5761,Bava Metzia 36",
		"23 Cheshvan 5761,Bava Metzia 37",
		"24 Cheshvan 5761,Bava Batra 1",
		"25 Cheshvan 5761,Bava Batra 2",
		"26 Cheshvan 5761,Bava Batra 3",
		"27 Cheshvan 5761,Bava Batra 4",
		"28 Cheshvan 5761,Bava Batra 5",
		"29 Cheshvan 5761,Bava Batra 6",
		"1 Kislev 5761,Bava Batra 7",
		"2 Kislev 5761,Bava Batra 8",
		"3 Kislev 5761,Bava Batra 9",
		"4 Kislev 5761,Bava Batra 10",
		"5 Kislev 5761,Bava Batra 11",
		"6 Kislev 5761,Bava Batra 12",
		"7 Kislev 5761,Bava Batra 13",
		"8 Kislev 5761,Bava Batra 14",
		"9 Kislev 5761,Bava Batra 15",
		"10 Kislev 5761,Bava Batra 16",
		"11 Kislev 5761,Bava Batra 17",
		"12 Kislev 5761,Bava Batra 18",
		"13 Kislev 5761,Bava Batra 19",
		"14 Kislev 5761,Bava Batra 20",
		"15 Kislev 5761,Bava Batra 21",
		"16 Kislev 5761,Bava Batra 22",
		"17 Kislev 5761,Bava Batra 23",
		"18 Kislev 5761,Bava Batra 24",
		"19 Kislev 5761,Bava Batra 25",
		"20 Kislev 5761,Bava Batra 26",
		"21 Kislev 5761,Bava Batra 27",
		"22 Kislev 5761,Bava Batra 28",
		"23 Kislev 5761,Bava Batra 29",
		"24 Kislev 5761,Bava Batra 30",
		"25 Kislev 5761,Bava Batra 31",
		"26 Kislev 5761,Bava Batra 32",
		"27 Kislev 5761,Bava Batra 33",
		"28 Kislev 5761,Bava Batra 34",
		"29 Kislev 5761,Shevuot 1",
		"1 Tevet 5761,Shevuot 2",
		"2 Tevet 5761,Shevuot 3",
		"3 Tevet 5761,Shevuot 4",
		"4 Tevet 5761,Shevuot 5",
		"5 Tevet 5761,Shevuot 6",
		"6 Tevet 5761,Shevuot 7",
		"7 Tevet 5761,Shevuot 8",
		"8 Tevet 5761,Shevuot 9",
		"9 Tevet 5761,Shevuot 10",
		"10 Tevet 5761,Shevuot 11",
		"11 Tevet 5761,Shevuot 12",
		"12 Tevet 5761,Shevuot 13",
		"13 Tevet 5761,Shevuot 14",
		"14 Tevet 5761,Shevuot 15",
		"15 Tevet 5761,Shevuot 16",
		"16 Tevet 5761,Shevuot 17",
		"17 Tevet 5761,Shevuot 18",
		"18 Tevet 5761,Shevuot 19",
		"19 Tevet 5761,Shevuot 20",
		"20 Tevet 5761,Shevuot 21",
		"21 Tevet 5761,Shevuot 22",
		"22 Tevet 5761,Shevuot 23",
		"23 Tevet 5761,Shevuot 24",
		"24 Tevet 5761,Shevuot 25",
		"25 Tevet 5761,Shevuot 26",
		"26 Tevet 5761,Shevuot 27",
		"27 Tevet 5761,Shevuot 28",
		"28 Tevet 5761,Shevuot 29",
		"29 Tevet 5761,Shevuot 30",
		"1 Sh'vat 5761,Shevuot 31",
		"2 Sh'vat 5761,Shevuot 32",
		"3 Sh'vat 5761,Shevuot 33",
		"4 Sh'vat 5761,Shevuot 34",
		"5 Sh'vat 5761,Shevuot 35",
		"6 Sh'vat 5761,Shevuot 36",
		"7 Sh'vat 5761,Shevuot 37",
		"8 Sh'vat 5761,Shevuot 38",
		"9 Sh'vat 5761,Shevuot 39",
		"10 Sh'vat 5761,Shevuot 40",
		"11 Sh'vat 5761,Shevuot 41",
		"12 Sh'vat 5761,Shevuot 42",
		"13 Sh'vat 5761,Shevuot 43",
		"14 Sh'vat 5761,Shevuot 44",
		"15 Sh'vat 5761,Makkot 1",
		"16 Sh'vat 5761,Makkot 2",
		"17 Sh'vat 5761,Makkot 3",
		"18 Sh'vat 5761,Makkot 4",
		"19 Sh'vat 5761,Makkot 5",
		"20 Sh'vat 5761,Makkot 6",
		"21 Sh'vat 5761,Makkot 7",
		"22 Sh'vat 5761,Makkot 8",
		"23 Sh'vat 5761,Makkot 9",
		"24 Sh'vat 5761,Sanhedrin 1",
		"25 Sh'vat 5761,Sanhedrin 2",
		"26 Sh'vat 5761,Sanhedrin 3",
		"27 Sh'vat 5761,Sanhedrin 4",
		"28 Sh'vat 5761,Sanhedrin 5",
		"29 Sh'vat 5761,Sanhedrin 6",
		"30 Sh'vat 5761,Sanhedrin 7",
		"1 Adar 5761,Sanhedrin 8",
		"2 Adar 5761,Sanhedrin 9",
		"3 Adar 5761,Sanhedrin 10",
		"4 Adar 5761,Sanhedrin 11",
		"5 Adar 5761,Sanhedrin 12",
		"6 Adar 5761,Sanhedrin 13",
		"7 Adar 5761,Sanhedrin 14",
		"8 Adar 5761,Sanhedrin 15",
		"9 Adar 5761,Sanhedrin 16",
		"10 Adar 5761,Sanhedrin 17",
		"11 Adar 5761,Sanhedrin 18",
		"12 Adar 5761,Sanhedrin 19",
		"13 Adar 5761,Sanhedrin 20",
		"14 Adar 5761,Sanhedrin 21",
		"15 Adar 5761,Sanhedrin 22",
		"16 Adar 5761,Sanhedrin 23",
		"17 Adar 5761,Sanhedrin 24",
		"18 Adar 5761,Sanhedrin 25",
		"19 Adar 5761,Sanhedrin 26",
		"20 Adar 5761,Sanhedrin 27",
		"21 Adar 5761,Sanhedrin 28",
		"22 Adar 5761,Sanhedrin 29",
		"23 Adar 5761,Sanhedrin 30",
		"24 Adar 5761,Sanhedrin 31",
		"25 Adar 5761,Sanhedrin 32",
		"26 Adar 5761,Sanhedrin 33",
		"27 Adar 5761,Sanhedrin 34",
		"28 Adar 5761,Sanhedrin 35",
		"29 Adar 5761,Sanhedrin 36",
		"1 Nisan 5761,Sanhedrin 37",
		"2 Nisan 5761,Sanhedrin 38",
		"3 Nisan 5761,Sanhedrin 39",
		"4 Nisan 5761,Sanhedrin 40",
		"5 Nisan 5761,Sanhedrin 41",
		"6 Nisan 5761,Sanhedrin 42",
		"7 Nisan 5761,Sanhedrin 43",
		"8 Nisan 5761,Sanhedrin 44",
		"9 Nisan 5761,Sanhedrin 45",
		"10 Nisan 5761,Sanhedrin 46",
		"11 Nisan 5761,Sanhedrin 47",
		"12 Nisan 5761,Sanhedrin 48",
		"13 Nisan 5761,Sanhedrin 49",
		"14 Nisan 5761,Sanhedrin 50",
		"15 Nisan 5761,Sanhedrin 51",
		"16 Nisan 5761,Sanhedrin 52",
		"17 Nisan 5761,Sanhedrin 53",
		"18 Nisan 5761,Sanhedrin 54",
		"19 Nisan 5761,Sanhedrin 55",
		"20 Nisan 5761,Sanhedrin 56",
		"21 Nisan 5761,Sanhedrin 57",
		"22 Nisan 5761,Avodah Zarah 1",
		"23 Nisan 5761,Avodah Zarah 2",
		"24 Nisan 5761,Avodah Zarah 3",
		"25 Nisan 5761,Avodah Zarah 4",
		"26 Nisan 5761,Avodah Zarah 5",
		"27 Nisan 5761,Avodah Zarah 6",
		"28 Nisan 5761,Avodah Zarah 7",
		"29 Nisan 5761,Avodah Zarah 8",
		"30 Nisan 5761,Avodah Zarah 9",
		"1 Iyyar 5761,Avodah Zarah 10",
		"2 Iyyar 5761,Avodah Zarah 11",
		"3 Iyyar 5761,Avodah Zarah 12",
		"4 Iyyar 5761,Avodah Zarah 13",
		"5 Iyyar 5761,Avodah Zarah 14",
		"6 Iyyar 5761,Avodah Zarah 15",
		"7 Iyyar 5761,Avodah Zarah 16",
		"8 Iyyar 5761,Avodah Zarah 17",
		"9 Iyyar 5761,Avodah Zarah 18",
		"10 Iyyar 5761,Avodah Zarah 19",
		"11 Iyyar 5761,Avodah Zarah 20",
		"12 Iyyar 5761,Avodah Zarah 21",
		"13 Iyyar 5761,Avodah Zarah 22",
		"14 Iyyar 5761,Avodah Zarah 23",
		"15 Iyyar 5761,Avodah Zarah 24",
		"16 Iyyar 5761,Avodah Zarah 25",
		"17 Iyyar 5761,Avodah Zarah 26",
		"18 Iyyar 5761,Avodah Zarah 27",
		"19 Iyyar 5761,Avodah Zarah 28",
		"20 Iyyar 5761,Avodah Zarah 29",
		"21 Iyyar 5761,Avodah Zarah 30",
		"22 Iyyar 5761,Avodah Zarah 31",
		"23 Iyyar 5761,Avodah Zarah 32",
		"24 Iyyar 5761,Avodah Zarah 33",
		"25 Iyyar 5761,Avodah Zarah 34",
		"26 Iyyar 5761,Avodah Zarah 35",
		"27 Iyyar 5761,Avodah Zarah 36",
		"28 Iyyar 5761,Avodah Zarah 37",
		"29 Iyyar 5761,Horayot 1",
		"1 Sivan 5761,Horayot 2",
		"2 Sivan 5761,Horayot 3",
		"3 Sivan 5761,Horayot 4",
		"4 Sivan 5761,Horayot 5",
		"5 Sivan 5761,Horayot 6",
		"6 Sivan 5761,Horayot 7",
		"7 Sivan 5761,Horayot 8",
		"8 Sivan 5761,Horayot 9",
		"9 Sivan 5761,Horayot 10",
		"10 Sivan 5761,Horayot 11",
		"11 Sivan 5761,Horayot 12",
		"12 Sivan 5761,Horayot 13",
		"13 Sivan 5761,Horayot 14",
		"14 Sivan 5761,Horayot 15",
		"15 Sivan 5761,Horayot 16",
		"16 Sivan 5761,Horayot 17",
		"17 Sivan 5761,Horayot 18",
		"18 Sivan 5761,Horayot 19",
		"19 Sivan 5761,Niddah 1",
		"20 Sivan 5761,Niddah 2",
		"21 Sivan 5761,Niddah 3",
		"22 Sivan 5761,Niddah 4",
		"23 Sivan 5761,Niddah 5",
		"24 Sivan 5761,Niddah 6",
		"25 Sivan 5761,Niddah 7",
		"26 Sivan 5761,Niddah 8",
		"27 Sivan 5761,Niddah 9",
		"28 Sivan 5761,Niddah 10",
		"29 Sivan 5761,Niddah 11",
		"30 Sivan 5761,Niddah 12",
		"1 Tamuz 5761,Niddah 13",
	}
	assert.Equal(t, expected, actual)
}

func ExampleNew() {
	hd := hdate.FromGregorian(1995, time.December, 17)
	daf := yerushalmi.New(hd, yerushalmi.Vilna)
	fmt.Println(daf)
	// Output: Nedarim 33
}
